@@ -118,10 +118,10 @@ class GerritWatcher(threading.Thread):
         """
         super(GerritWatcher, self).__init__()
         self.connection = GerritConnection(
-            username or gerrit.username,
-            hostname or gerrit.hostname,
-            port or gerrit.port,
-            keyfile or gerrit.keyfile,
+            username or gerrit.connection.username,
+            hostname or gerrit.connection.hostname,
+            port or gerrit.connection.port,
+            keyfile or gerrit.connection.keyfile,
             connection_attempts,
             retry_delay
         )
@@ -202,7 +202,7 @@ class Gerrit(object):
 
     def startWatching(self, connection_attempts=-1, retry_delay=5):
         self.event_queue = six.moves.queue.Queue()
-        watcher = GerritWatcher(self.connection,
+        watcher = GerritWatcher(self,
                                 connection_attempts=connection_attempts,
                                 retry_delay=retry_delay)
         self.watcher_thread = watcher
@@ -428,13 +428,13 @@ class Gerrit(object):
             self.log.debug("SSH command:\n%s" % command)
             stdin, stdout, stderr = self.client.exec_command(command)
 
-            out = stdout.read()
+            out = stdout.read().decode('utf8')
             self.log.debug("SSH received stdout:\n%s" % out)
 
             ret = stdout.channel.recv_exit_status()
             self.log.debug("SSH exit status: %s" % ret)
 
-            err = stderr.read()
+            err = stderr.read().decode('utf8')
             self.log.debug("SSH received stderr:\n%s" % err)
             if ret:
                 raise Exception("Gerrit error executing %s" % command)
